@@ -18,22 +18,26 @@ from mercurial import (
     commands,
     error,
     extensions,
+    registrar,
 )
 
 cmdtable = {}
-command = cmdutil.command(cmdtable)
-# Note for extension authors: ONLY specify testedwith = 'internal' for
+command = registrar.command(cmdtable)
+# Note for extension authors: ONLY specify testedwith = 'ships-with-hg-core' for
 # extensions which SHIP WITH MERCURIAL. Non-mainline extensions should
 # be specifying the version(s) of Mercurial they are tested with, or
 # leave the attribute unspecified.
-testedwith = 'internal'
+testedwith = b'ships-with-hg-core'
 
 
-@command("record",
-         # same options as commit + white space diff options
-        [c for c in commands.table['^commit|ci'][1][:]
-            if c[1] != "interactive"] + commands.diffwsopts,
-          _('hg record [OPTION]... [FILE]...'))
+@command(
+    b"record",
+    # same options as commit + white space diff options
+    [c for c in commands.table[b'commit|ci'][1][:] if c[1] != b"interactive"]
+    + cmdutil.diffwsopts,
+    _(b'hg record [OPTION]... [FILE]...'),
+    helpcategory=command.CATEGORY_COMMITTING,
+)
 def record(ui, repo, *pats, **opts):
     '''interactively select changes to commit
 
@@ -42,7 +46,8 @@ def record(ui, repo, *pats, **opts):
 
     See :hg:`help dates` for a list of formats valid for -d/--date.
 
-    You will be prompted for whether to record changes to each
+    If using the text interface (see :hg:`help config`),
+    you will be prompted for whether to record changes to each
     modified file, and for files with multiple changes, for each
     change to use. For each query, the following responses are
     possible::
@@ -63,22 +68,21 @@ def record(ui, repo, *pats, **opts):
     This command is not available when committing a merge.'''
 
     if not ui.interactive():
-        raise error.Abort(_('running non-interactively, use %s instead') %
-                         'commit')
+        raise error.Abort(
+            _(b'running non-interactively, use %s instead') % b'commit'
+        )
+
+    opts[r"interactive"] = True
+    overrides = {(b'experimental', b'crecord'): False}
+    with ui.configoverride(overrides, b'record'):
+        return commands.commit(ui, repo, *pats, **opts)
 
-    opts["interactive"] = True
-    backup = ui.backupconfig('experimental', 'crecord')
-    try:
-        ui.setconfig('experimental', 'crecord', False, 'record')
-        commands.commit(ui, repo, *pats, **opts)
-    finally:
-        ui.restoreconfig(backup)
 
 def qrefresh(origfn, ui, repo, *pats, **opts):
-    if not opts['interactive']:
+    if not opts[r'interactive']:
         return origfn(ui, repo, *pats, **opts)
 
-    mq = extensions.find('mq')
+    mq = extensions.find(b'mq')
 
     def committomq(ui, repo, *pats, **opts):
         # At this point the working copy contains only changes that
@@ -88,65 +92,84 @@ def qrefresh(origfn, ui, repo, *pats, **opts):
         mq.refresh(ui, repo, **opts)
 
     # backup all changed files
-    cmdutil.dorecord(ui, repo, committomq, None, True,
-                    cmdutil.recordfilter, *pats, **opts)
+    cmdutil.dorecord(
+        ui, repo, committomq, None, True, cmdutil.recordfilter, *pats, **opts
+    )
+
 
 # This command registration is replaced during uisetup().
-@command('qrecord',
+@command(
+    b'qrecord',
     [],
-    _('hg qrecord [OPTION]... PATCH [FILE]...'),
-    inferrepo=True)
+    _(b'hg qrecord [OPTION]... PATCH [FILE]...'),
+    helpcategory=command.CATEGORY_COMMITTING,
+    inferrepo=True,
+)
 def qrecord(ui, repo, patch, *pats, **opts):
     '''interactively record a new patch
 
     See :hg:`help qnew` & :hg:`help record` for more information and
     usage.
     '''
-    return _qrecord('qnew', ui, repo, patch, *pats, **opts)
+    return _qrecord(b'qnew', ui, repo, patch, *pats, **opts)
+
 
 def _qrecord(cmdsuggest, ui, repo, patch, *pats, **opts):
     try:
-        mq = extensions.find('mq')
+        mq = extensions.find(b'mq')
     except KeyError:
-        raise error.Abort(_("'mq' extension not loaded"))
+        raise error.Abort(_(b"'mq' extension not loaded"))
 
     repo.mq.checkpatchname(patch)
 
     def committomq(ui, repo, *pats, **opts):
-        opts['checkname'] = False
+        opts[r'checkname'] = False
         mq.new(ui, repo, patch, *pats, **opts)
 
-    backup = ui.backupconfig('experimental', 'crecord')
-    try:
-        ui.setconfig('experimental', 'crecord', False, 'record')
-        cmdutil.dorecord(ui, repo, committomq, cmdsuggest, False,
-                         cmdutil.recordfilter, *pats, **opts)
-    finally:
-        ui.restoreconfig(backup)
+    overrides = {(b'experimental', b'crecord'): False}
+    with ui.configoverride(overrides, b'record'):
+        cmdutil.checkunfinished(repo)
+        cmdutil.dorecord(
+            ui,
+            repo,
+            committomq,
+            cmdsuggest,
+            False,
+            cmdutil.recordfilter,
+            *pats,
+            **opts
+        )
+
 
 def qnew(origfn, ui, repo, patch, *args, **opts):
-    if opts['interactive']:
+    if opts[r'interactive']:
         return _qrecord(None, ui, repo, patch, *args, **opts)
     return origfn(ui, repo, patch, *args, **opts)
 
 
 def uisetup(ui):
     try:
-        mq = extensions.find('mq')
+        mq = extensions.find(b'mq')
     except KeyError:
         return
 
-    cmdtable["qrecord"] = \
-        (qrecord,
-         # same options as qnew, but copy them so we don't get
-         # -i/--interactive for qrecord and add white space diff options
-         mq.cmdtable['^qnew'][1][:] + commands.diffwsopts,
-         _('hg qrecord [OPTION]... PATCH [FILE]...'))
+    cmdtable[b"qrecord"] = (
+        qrecord,
+        # same options as qnew, but copy them so we don't get
+        # -i/--interactive for qrecord and add white space diff options
+        mq.cmdtable[b'qnew'][1][:] + cmdutil.diffwsopts,
+        _(b'hg qrecord [OPTION]... PATCH [FILE]...'),
+    )
+
+    _wrapcmd(b'qnew', mq.cmdtable, qnew, _(b"interactively record a new patch"))
+    _wrapcmd(
+        b'qrefresh',
+        mq.cmdtable,
+        qrefresh,
+        _(b"interactively select changes to refresh"),
+    )
 
-    _wrapcmd('qnew', mq.cmdtable, qnew, _("interactively record a new patch"))
-    _wrapcmd('qrefresh', mq.cmdtable, qrefresh,
-             _("interactively select changes to refresh"))
 
 def _wrapcmd(cmd, table, wrapfn, msg):
     entry = extensions.wrapcommand(table, cmd, wrapfn)
-    entry[1].append(('i', 'interactive', None, msg))
+    entry[1].append((b'i', b'interactive', None, msg))
